@@ -84,13 +84,3 @@ pub fn app() -> App<'static> {
             "zsh",
         ]))
 }
-
-#[cfg(test)]
-mod tests {
-    use super::app;
-
-    #[test]
-    fn package_name() {
-        assert_eq!(app().get_name(), env!("CARGO_PKG_NAME"));
-    }
-}
